summaryrefslogtreecommitdiff
path: root/sfx2
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2014-09-27 14:52:40 +0200
committerNoel Grandin <noel@peralex.com>2014-09-30 09:58:23 +0200
commit8dbde0845a3989528614addb9bd0333f60c522a5 (patch)
treec1f13bfc8e2841427eb6a07e2147445b309b1e9a /sfx2
parentb69478acff4f5b7a9d334a765a1a528d44d7b3a4 (diff)
fdo#82577: Handle Region
Put the VCL Region class in the vcl namespace. Avoids clash with the X11 Region typedef. Change-Id: I6e008111df7cf37121fbc3eaabd44a8306338291
Diffstat (limited to 'sfx2')
-rw-r--r--sfx2/source/dialog/backingwindow.cxx2
-rw-r--r--sfx2/source/doc/doctempl.cxx40
-rw-r--r--sfx2/source/doc/objembed.cxx2
3 files changed, 22 insertions, 22 deletions
diff --git a/sfx2/source/dialog/backingwindow.cxx b/sfx2/source/dialog/backingwindow.cxx
index c31839e4c522..ce4e923f3872 100644
--- a/sfx2/source/dialog/backingwindow.cxx
+++ b/sfx2/source/dialog/backingwindow.cxx
@@ -348,7 +348,7 @@ void BackingWindow::Paint( const Rectangle& )
Resize();
Wallpaper aBack( svtools::ColorConfig().GetColorValue(::svtools::APPBACKGROUND).nColor );
- Region aClip( Rectangle( Point( 0, 0 ), GetOutputSizePixel() ) );
+ vcl::Region aClip( Rectangle( Point( 0, 0 ), GetOutputSizePixel() ) );
aClip.Exclude( maStartCentButtons );
diff --git a/sfx2/source/doc/objembed.cxx b/sfx2/source/doc/objembed.cxx
index 7c69dc8a6238..1ce7b6717fdb 100644
--- a/sfx2/source/doc/objembed.cxx
+++ b/sfx2/source/doc/objembed.cxx
@@ -212,7 +212,7 @@ void SfxObjectShell::DoDraw_Impl( OutputDevice* pDev,
// Secure the Device settings
pDev->Push();
- Region aRegion;
+ vcl::Region aRegion;
if( pDev->IsClipRegion() && pDev->GetOutDevType() != OUTDEV_PRINTER )
{
aRegion = pDev->GetClipRegion();
diff --git a/sfx2/source/doc/doctempl.cxx b/sfx2/source/doc/doctempl.cxx
index 19950c02e293..b2c352efdd5c 100644
--- a/sfx2/source/doc/doctempl.cxx
+++ b/sfx2/source/doc/doctempl.cxx
@@ -277,14 +277,14 @@ static bool getTextProperty_Impl( Content& rContent,
OUString SfxDocumentTemplates::GetFullRegionName
(
- sal_uInt16 nIdx // Region Index
+ sal_uInt16 nIdx // vcl::Region Index
) const
/* [Description]
Returns the logical name of a region and its path
- [Return value] Reference to the Region name
+ [Return value] Reference to the vcl::Region name
*/
@@ -313,7 +313,7 @@ OUString SfxDocumentTemplates::GetFullRegionName
const OUString& SfxDocumentTemplates::GetRegionName
(
- sal_uInt16 nIdx // Region Index
+ sal_uInt16 nIdx // vcl::Region Index
) const
/* [Description]
@@ -322,7 +322,7 @@ const OUString& SfxDocumentTemplates::GetRegionName
[Return value]
- const String& Reference to the Region name
+ const String& Reference to the vcl::Region name
*/
{
@@ -372,7 +372,7 @@ sal_uInt16 SfxDocumentTemplates::GetRegionCount() const
sal_uInt16 SfxDocumentTemplates::GetCount
(
- sal_uInt16 nRegion /* Region index whose number is
+ sal_uInt16 nRegion /* vcl::Region index whose number is
to be determined */
) const
@@ -403,7 +403,7 @@ sal_uInt16 SfxDocumentTemplates::GetCount
const OUString& SfxDocumentTemplates::GetName
(
- sal_uInt16 nRegion, // Region Index, in which the entry lies
+ sal_uInt16 nRegion, // vcl::Region Index, in which the entry lies
sal_uInt16 nIdx // Index of the entry
) const
@@ -444,7 +444,7 @@ const OUString& SfxDocumentTemplates::GetName
OUString SfxDocumentTemplates::GetPath
(
- sal_uInt16 nRegion, // Region Index, in which the entry lies
+ sal_uInt16 nRegion, // vcl::Region Index, in which the entry lies
sal_uInt16 nIdx // Index of the entry
) const
@@ -534,9 +534,9 @@ OUString SfxDocumentTemplates::ConvertResourceString (
bool SfxDocumentTemplates::CopyOrMove
(
- sal_uInt16 nTargetRegion, // Target Region Index
+ sal_uInt16 nTargetRegion, // Target vcl::Region Index
sal_uInt16 nTargetIdx, // Target position Index
- sal_uInt16 nSourceRegion, // Source Region Index
+ sal_uInt16 nSourceRegion, // Source vcl::Region Index
sal_uInt16 nSourceIdx, /* Index to be copied / to moved template */
bool bMove // Copy / Move
)
@@ -640,9 +640,9 @@ bool SfxDocumentTemplates::CopyOrMove
bool SfxDocumentTemplates::Move
(
- sal_uInt16 nTargetRegion, // Target Region Index
+ sal_uInt16 nTargetRegion, // Target vcl::Region Index
sal_uInt16 nTargetIdx, // Target position Index
- sal_uInt16 nSourceRegion, // Source Region Index
+ sal_uInt16 nSourceRegion, // Source vcl::Region Index
sal_uInt16 nSourceIdx /* Index to be copied / to moved template */
)
@@ -670,9 +670,9 @@ bool SfxDocumentTemplates::Move
bool SfxDocumentTemplates::Copy
(
- sal_uInt16 nTargetRegion, // Target Region Index
+ sal_uInt16 nTargetRegion, // Target vcl::Region Index
sal_uInt16 nTargetIdx, // Target position Index
- sal_uInt16 nSourceRegion, // Source Region Index
+ sal_uInt16 nSourceRegion, // Source vcl::Region Index
sal_uInt16 nSourceIdx /* Index to be copied / to moved template */
)
@@ -701,7 +701,7 @@ bool SfxDocumentTemplates::Copy
bool SfxDocumentTemplates::CopyTo
(
- sal_uInt16 nRegion, // Region of the template to be exported
+ sal_uInt16 nRegion, // vcl::Region of the template to be exported
sal_uInt16 nIdx, // Index of the template to be exported
const OUString& rName /* File name under which the template is to
be created */
@@ -773,7 +773,7 @@ bool SfxDocumentTemplates::CopyTo
bool SfxDocumentTemplates::CopyFrom
(
- sal_uInt16 nRegion, /* Region in which the template is to be
+ sal_uInt16 nRegion, /* vcl::Region in which the template is to be
imported */
sal_uInt16 nIdx, // Index of the new template in this Region
OUString& rName /* File name of the template to be imported
@@ -918,7 +918,7 @@ bool SfxDocumentTemplates::CopyFrom
bool SfxDocumentTemplates::Delete
(
- sal_uInt16 nRegion, // Region Index
+ sal_uInt16 nRegion, // vcl::Region Index
sal_uInt16 nIdx /* Index of the entry or USHRT_MAX,
if a directory is meant. */
)
@@ -983,7 +983,7 @@ bool SfxDocumentTemplates::Delete
bool SfxDocumentTemplates::InsertDir
(
const OUString& rText, // the logical name of the new Region
- sal_uInt16 nRegion // Region Index
+ sal_uInt16 nRegion // vcl::Region Index
)
/* [Description]
@@ -1103,7 +1103,7 @@ bool SfxDocumentTemplates::SetName( const OUString& rName, sal_uInt16 nRegion, s
bool SfxDocumentTemplates::GetFull
(
- const OUString &rRegion, // Region Name
+ const OUString &rRegion, // vcl::Region Name
const OUString &rName, // Template Name
OUString &rPath // Out: Path + File name
)
@@ -1160,7 +1160,7 @@ bool SfxDocumentTemplates::GetFull
bool SfxDocumentTemplates::GetLogicNames
(
const OUString &rPath, // Full Path to the template
- OUString &rRegion, // Out: Region name
+ OUString &rRegion, // Out: vcl::Region name
OUString &rName // Out: Template name
) const
@@ -1578,7 +1578,7 @@ void SfxDocTemplate_Impl::DeleteRegion( size_t nIndex )
}
/* AddRegion adds a Region to the RegionList
*/
void SfxDocTemplate_Impl::AddRegion( const OUString& rTitle,
Content& rContent )
@@ -1578,7 +1578,7 @@ void SfxDocTemplate_Impl::DeleteRegion( size_t nIndex )
}
-/* AddRegion adds a Region to the RegionList
+/* AddRegion adds a vcl::Region to the RegionList
*/
void SfxDocTemplate_Impl::AddRegion( const OUString& rTitle,